<?php
/**
 * @file
 * Contains page callbacks and related functions of TCPDF module.
 */

/**
 * Page callback for contents page.
 */
function tcpdf_example_contents() {
  return l(t('Basic pdf'), 'tcpdf_example/download/simple');
}

/**
 * Page callback for downloading example pdf files.
 */
function tcpdf_example_download($example_name) {
  switch ($example_name) {
    case 'simple':
      $pdf = tcpdf_example_simple_pdf();
      break;
    default:
      return t('No such example.');
  }

  if (!$pdf) {
    return t('An error occured.');
  }

  // Tell the browser that this is not an HTML file to show, but a pdf file to
  // download.
  header('Content-Type: application/pdf');
  header('Content-Length: ' . strlen($pdf));
  header('Content-Disposition: attachment; filename="mydocument.pdf"');
  print $pdf;
  return NULL;
}

/**
 * Generates a pdf file using TCPDF module.
 *
 * @return string Binary string of the generated pdf.
 */
function tcpdf_example_simple_pdf() {
  // Get the content we want to convert into pdf.
  $html = theme('tcpdf_example_basic_html');

  // Never make an instance of TCPDF or TCPDFDrupal classes manually.
  // Use tcpdf_get_instance() instead.
  $tcpdf = tcpdf_get_instance();

  /* DrupalInitialize() is an extra method added to TCPDFDrupal that initializes
  *  some TCPDF variables (like font types), and makes possible to change the
  *  default header or footer without creating a new class.
  */
  $tcpdf->DrupalInitialize(array(
    'footer' => array(
      'html' => 'This is a test!! <em>Bottom of the page</em>',
    ),
    'header' => array(
      'callback' => 'tcpdf_example_default_header',
    ),
  ));
  // Insert the content. Note that DrupalInitialize automaticly adds the first
  // page to the pdf document.
  $tcpdf->writeHTML($html);

  return $tcpdf->Output('', 'S');
}

/**
 * Callback for generating the header. This function acts like if it overridded
 *   the Header() function of tcpdf class except the tcpdf instance is not $this
 *   but a parameter.
 *
 * @param type $tcpdf TCPDFDrupal instance. It can be used as $this in the
 *   Header() function of a siebling of TCPDF.
 */
function tcpdf_example_default_header(&$tcpdf) {
  $theme_settings = variable_get('theme_' . variable_get('theme_default', '') . '_settings', '');
  $logo_path = isset($theme_settings['logo_path']) ? $theme_settings['logo_path'] : PDF_HEADER_LOGO;
  $tcpdf->Image(drupal_realpath($logo_path), 10, 10, 30, 0, '', variable_get('site_url', ''), '', TRUE, 150, '', FALSE, FALSE, 0, FALSE, FALSE, FALSE);
}
